@@ -44,7 +44,8 @@ class User(BaseModel):
         first_name=None,
         last_name=None,
         email=None,
-        company=None
+        company=None,
+        pin=None
     ):
         
         super().__init__()
@@ -52,4 +53,5 @@ class User(BaseModel):
         self.first_name = first_name
         self.last_name = last_name
         self.email = email
-        self.company = company
\ No newline at end of file
+        self.company = company
+        self.pin = pin
\ No newline at end of file
